@@ -1,4 +1,5 @@
-#!perl
+#!/usr/bin/env perl
+# PODNAME: a minimal RDAP server.
 use Net::RDAP::Server;
 use constant ABOUT_URL => 'https://about.rdap.org';
 use strict;
@@ -46,8 +47,6 @@ sub head_domain { shift->ok }
 sub get_domain {
     my $response = shift;
 
-    my $now = DateTime->now;
-
     $response->ok;
 
     $response->content({
@@ -55,3 +54,30 @@ sub get_domain {
         ldhName => $response->request->object,
     });
 }
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+a minimal RDAP server.
+
+=head1 VERSION
+
+version 0.06
+
+=head1 AUTHOR
+
+Gavin Brown <gavin.brown@fastmail.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025 by Gavin Brown.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
